@@ -1,5 +1,7 @@
 #' Get list ITIS Synonyms for a Scientific Name
 #'
+#'  This function is depreciated. Please use \link{get_itis_syn}
+#'
 #' Fetch Synonyms using ITIS web service
 #'
 #' @param scname Scientific Name
@@ -7,11 +9,12 @@
 #' @importFrom taxize get_tsn synonyms
 #' @family ITIS functions
 #' @examples
-#' ListITISSyn("Abrothrix longipilis")
-#' ListITISSyn("Abditomys latidens")
+#' #ListITISSyn("Abrothrix longipilis")
+#' #ListITISSyn("Abditomys latidens")
 #'
 #' @export
 ListITISSyn <- function(scname){
+  .Deprecated("get_itis_syn")
   tsn <- get_tsn(scname, rows=1)[1]
   t1 <- NULL
   if(!is.na(tsn)){
